//-------------------------------------------------------------------------
// play-v6 - music player for ATmega328P @ 16 MHz
// top-level functions
// created 9 Dec 2013 by Enrico Colombini <erix@erix.it>
// license: CC Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
// http://creativecommons.org/licenses/by-sa/4.0/
//-------------------------------------------------------------------------

#ifndef PLAYER_H
#define PLAYER_H

//-------------------------------------------------------------------------
// constants (see pwm.h for PWM-related constants)

//baud rate for serial communication
#define SERIAL_BAUD_RATE        57600u

//inter-byte timeout in music serial loading
#define LOAD_BYTE_TIMEOUT_MS    100u

//maximum allowed length for music (play buffer size) in bytes,
//(this is conservative to allow space for extra variables & music stack)
#define MAX_MUSIC_LENGTH        1800u

//time between repeats
#define REPEAT_PAUSE_MS         1000u

//serial commands
#define SERIAL_CMD_NONE         '\0'
#define SERIAL_CMD_QUERY        '?'
#define SERIAL_CMD_LOAD         'L'
#define SERIAL_CMD_PLAY_TOGGLE  ' '
#define SERIAL_CMD_REPEAT       'R'
#define SERIAL_CMD_AUTOPLAY     'A'
#define SERIAL_CMD_NEXT         '+'
#define SERIAL_CMD_PREV         '-'

//serial replies
#define SERIAL_REPLY_OK         '.'
#define SERIAL_REPLY_ERROR      '*'
#define SERIAL_REPLY_PLAYING    '-'

//-------------------------------------------------------------------------
// public functions

void PlayerMain(void);

//-------------------------------------------------------------------------

#endif //PLAYER_H